@@ -5,10 +5,11 @@
 
 	serif: "Serife",
 	"sans-serif": "Serifenlos",
-	monospaced: "Monospace",
+	monospace: "Monospaceschrift",
 	cursive: "Kursiv",
 	fantasy: "Fantasie",
 
+	noFormat: "Keine Angabe",
 	p: "Absatz",
 	h1: "Überschrift",
 	h2: "Unterüberschrift",
@@ -22,4 +23,4 @@
 	5: "L",
 	6: "XL",
 	7: "XXL"
-})
\ No newline at end of file
+})
