@@ -1,12 +1,25 @@
 <?php
-
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
  */
 
-
 /**
  * Zend_Mail_Storage_Maildir
  */
@@ -17,16 +30,13 @@ require_once 'Zend/Mail/Storage/Maildir.php';
  */
 require_once 'Zend/Config.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
 /**
  * @category   Zend
  * @package    Zend_Mail
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Mail
  */
 class Zend_Mail_MaildirTest extends PHPUnit_Framework_TestCase
 {
@@ -394,23 +404,45 @@ class Zend_Mail_MaildirTest extends PHPUnit_Framework_TestCase
     public function testCountFlags()
     {
         $mail = new Zend_Mail_Storage_Maildir(array('dirname' => $this->_maildir));
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_DELETED), 0);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_RECENT), 1);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 1);
-		$this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 4);
-		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_FLAGGED)), 1);
-		$this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_RECENT)), 0);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_DELETED), 0);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_RECENT), 1);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_FLAGGED), 1);
+        $this->assertEquals($mail->countMessages(Zend_Mail_Storage::FLAG_SEEN), 4);
+        $this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_FLAGGED)), 1);
+        $this->assertEquals($mail->countMessages(array(Zend_Mail_Storage::FLAG_SEEN, Zend_Mail_Storage::FLAG_RECENT)), 0);
     }
 
-	public function testFetchPart()
-	{
+    public function testFetchPart()
+    {
         $mail = new Zend_Mail_Storage_Maildir(array('dirname' => $this->_maildir));
         $this->assertEquals($mail->getMessage(4)->getPart(2)->contentType, 'text/x-vertical');
-	}
+    }
 
-	public function testPartSize()
-	{
+    public function testPartSize()
+    {
         $mail = new Zend_Mail_Storage_Maildir(array('dirname' => $this->_maildir));
         $this->assertEquals($mail->getMessage(4)->getPart(2)->getSize(), 88);
-	}
+    }
+
+    public function testSizePlusPlus()
+    {
+        rename($this->_maildir . '/cur/1000000000.P1.example.org:2,S', $this->_maildir . '/cur/1000000000.P1.example.org,S=123:2,S');
+        rename($this->_maildir . '/cur/1000000001.P1.example.org:2,FS', $this->_maildir . '/cur/1000000001.P1.example.org,S=456:2,FS');
+        $mail = new Zend_Mail_Storage_Maildir(array('dirname' => $this->_maildir));
+        $shouldSizes = array(1 => 123, 456, 694, 452, 497);
+
+
+        $sizes = $mail->getSize();
+        $this->assertEquals($shouldSizes, $sizes);
+    }
+
+    public function testSingleSizePlusPlus()
+    {
+        rename($this->_maildir . '/cur/1000000001.P1.example.org:2,FS', $this->_maildir . '/cur/1000000001.P1.example.org,S=456:2,FS');
+        $mail = new Zend_Mail_Storage_Maildir(array('dirname' => $this->_maildir));
+
+        $size = $mail->getSize(2);
+        $this->assertEquals(456, $size);
+    }
+
 }
