@@ -15,16 +15,11 @@
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: MovableTest.php 8468 2008-02-29 17:56:34Z darby $
+ * @version    $Id$
  */
 
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
 /** Zend_Memory */
 require_once 'Zend/Memory.php';
 
@@ -36,7 +31,7 @@ require_once 'Zend/Memory.php';
  * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  */
 class Zend_Memory_Manager_Dummy extends Zend_Memory_Manager
@@ -71,8 +66,12 @@ class Zend_Memory_Manager_Dummy extends Zend_Memory_Manager
 
 
 /**
+ * @category   Zend
  * @package    Zend_Memory
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Memory
  */
 class Zend_Memory_Container_MovableTest extends PHPUnit_Framework_TestCase
 {
