@@ -15,7 +15,7 @@
  * @category   Zend
  * @package    Zend_Test
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @version    $Id$
  */
@@ -24,16 +24,11 @@ require_once "Zend/Test/DbAdapter.php";
 
 require_once "Zend/Test/PHPUnit/Db/Operation/DeleteAll.php";
 
-require_once "PHPUnit/Extensions/Database/DataSet/FlatXmlDataSet.php";
-
-require_once 'PHPUnit/Extensions/Database/DataSet/IDataSet.php';
-require_once 'PHPUnit/Extensions/Database/DB/IDatabaseConnection.php';
-
 /**
  * @category   Zend
  * @package    Zend_Test
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Test
  */
